==> ssp-center-api-0.5.93sjq-20191029.101022-1-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/QuestionSearchDto.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import org.apache.commons.lang3.builder.ToStringBuilder;

/**
 * @author shenjiaqing
 * @description
 * @data 2019/10/28
 */
public class QuestionSearchDto extends BaseQueryDto {

    private Long accountId;

    private String questionFirstTime;

    private String questionLastTime;

    private String questionContent;

    private Long disposeId;

    private Integer disposeStatus;

    private Integer questionStatus;

    private String questionCategory;

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public Long getDisposeId() {
        return disposeId;
    }

    public void setDisposeId(Long disposeId) {
        this.disposeId = disposeId;
    }

    public String getQuestionFirstTime() {
        return questionFirstTime;
    }

    public void setQuestionFirstTime(String questionFirstTime) {
        this.questionFirstTime = questionFirstTime;
    }

    public String getQuestionLastTime() {
        return questionLastTime;
    }

    public void setQuestionLastTime(String questionLastTime) {
        this.questionLastTime = questionLastTime;
    }

    public String getQuestionContent() {
        return questionContent;
    }

    public void setQuestionContent(String questionContent) {
        this.questionContent = questionContent;
    }


    public Integer getDisposeStatus() {
        return disposeStatus;
    }

    public void setDisposeStatus(Integer disposeStatus) {
        this.disposeStatus = disposeStatus;
    }

    public Integer getQuestionStatus() {
        return questionStatus;
    }

    public void setQuestionStatus(Integer questionStatus) {
        this.questionStatus = questionStatus;
    }

    public String getQuestionCategory() {
        return questionCategory;
    }

    public void setQuestionCategory(String questionCategory) {
        this.questionCategory = questionCategory;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}

==> ssp-center-api-0.6.08sjq-20191106.071742-1-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/QuestionSearchDto.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import org.apache.commons.lang3.builder.ToStringBuilder;

/**
 * @author shenjiaqing
 * @description
 * @data 2019/10/28
 */
public class QuestionSearchDto extends BaseQueryDto {

    private Long accountId;

    private String questionFirstTime;

    private String questionLastTime;

    private String questionContent;

    private Long disposeId;

    private Integer disposeStatus;

    private Integer questionStatus;

    private String questionCategoryId;

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public Long getDisposeId() {
        return disposeId;
    }

    public void setDisposeId(Long disposeId) {
        this.disposeId = disposeId;
    }

    public String getQuestionFirstTime() {
        return questionFirstTime;
    }

    public void setQuestionFirstTime(String questionFirstTime) {
        this.questionFirstTime = questionFirstTime;
    }

    public String getQuestionLastTime() {
        return questionLastTime;
    }

    public void setQuestionLastTime(String questionLastTime) {
        this.questionLastTime = questionLastTime;
    }

    public String getQuestionContent() {
        return questionContent;
    }

    public void setQuestionContent(String questionContent) {
        this.questionContent = questionContent;
    }


    public Integer getDisposeStatus() {
        return disposeStatus;
    }

    public void setDisposeStatus(Integer disposeStatus) {
        this.disposeStatus = disposeStatus;
    }

    public Integer getQuestionStatus() {
        return questionStatus;
    }

    public void setQuestionStatus(Integer questionStatus) {
        this.questionStatus = questionStatus;
    }

    public String getQuestionCategoryId() {
        return questionCategoryId;
    }

    public void setQuestionCategoryId(String questionCategoryId) {
        this.questionCategoryId = questionCategoryId;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}
